@@ -2,14 +2,11 @@ from __future__ import annotations
 from typing import List, Optional
 from pydantic import BaseModel
 
-from etsy_apiv3.models.ListingImageModel import ListingImage
-from etsy_apiv3.models.ProductionPartnerModel import ProductionPartner
-from etsy_apiv3.models.ShippingProfileModel import ShippingProfile
-from etsy_apiv3.models.ShopModel import Shop
-from etsy_apiv3.models.TranslationModel import Translation
-from etsy_apiv3.models.UserModel import User
-from etsy_apiv3.models.PriceModel import Price
-from etsy_apiv3.models.ProductModel import Product
+from . import (
+    ListingImage, ProductionPartner, ShippingProfile,
+    Shop, Translation, User,
+    Price, Product
+)
 
 class Inventory(BaseModel):
     products: List[Product]
@@ -19,7 +16,6 @@ class Inventory(BaseModel):
     listing: Optional[Listing]
 
 
-
 class Listing(BaseModel):
     listing_id: int
     user_id: int
