@@ -1,7 +1,7 @@
 from __future__ import annotations
 from typing import List
 from pydantic import BaseModel
-from etsy_apiv3.models.PriceModel import Price
+from . import Price
 
 class Offering(BaseModel):
     offering_id: int
