@@ -1,8 +1,7 @@
 from __future__ import annotations
 from typing import List
 from pydantic import BaseModel
-from etsy_apiv3.models.OfferingModel import Offering
-from etsy_apiv3.models.PropertyValueModel import PropertyValue
+from . import Offering, PropertyValue
 
 class Product(BaseModel):
     product_id: int
