@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 from typing import List, Optional
 from pydantic import BaseModel
-from etsy_apiv3.models.PriceModel import Price
-from etsy_apiv3.models.TransactionModel import Transaction
-from etsy_apiv3.models.ShipmentModel import Shipment
-from etsy_apiv3.models.RefundModel import Refund
 import pycountry
+from . import (
+    Price, Transaction, Shipment, Refund
+)
+
 
 
 
