@@ -1,6 +1,6 @@
 from __future__ import annotations
 from pydantic import BaseModel
-from etsy_apiv3.models.PriceModel import Price
+from . import Price
 
 class ShippingProfileDestination(BaseModel):
     shipping_profile_destination_id: int
