@@ -1,7 +1,8 @@
 from pydantic import BaseModel
 from typing import List
-from etsy_apiv3.models.ShippingProfileUpgradeModel import ShippingProfileUpgrade
-from etsy_apiv3.models.ShippingProfileDestinationModel import ShippingProfileDestination
+from . import (
+    ShippingProfileUpgrade, ShippingProfileDestination
+)
 
 class ShippingProfile(BaseModel):
     shipping_profile_id: int
