@@ -1,5 +1,5 @@
 from pydantic import BaseModel
-from etsy_apiv3.models.PriceModel import Price
+from . import Price
 
 class ShippingProfileUpgrade(BaseModel):
     shipping_profile_id: int
