@@ -1,8 +1,9 @@
 from __future__ import annotations
 from pydantic import BaseModel
 from typing import List, Optional
-from etsy_apiv3.models.PriceModel import Price
-from etsy_apiv3.models.VariationModel import Variation
+from . import (
+    Price, Variation
+)
 
 class Transaction(BaseModel):
     transaction_id: int
