@@ -1,14 +1,13 @@
 from dataclasses import dataclass
 from typing import List, Optional
-from etsy_apiv3.models.ListingPropertyModel import ListingProperty
-from etsy_apiv3.utils.APIV3 import EtsyAuth
+from etsy_apiv3.utils.APIV3 import EtsySession
 from etsy_apiv3.utils.Response import Response
-from etsy_apiv3.models.ListingModel import Listing, Inventory
+from ..models import Listing, Inventory, ListingProperty
 
 @dataclass
 class ListingResource:
     
-    auth: EtsyAuth
+    session: EtsySession
     
     def get_listing(self, listing_id: int, includes: str = "") -> Listing:
         """
@@ -22,7 +21,7 @@ class ListingResource:
             Listing: A Single Listing Object
         """
         endpoint = f"listings/{listing_id}"
-        json = self.auth.request(endpoint, params={"includes":includes})
+        json = self.session.request(endpoint, params={"includes":includes})
         return Listing(**json)
 
     def find_all_active_listings(self, limit=25, offset=0, keywords="", sort_on="created", sort_order="desc", min_price=None, max_price=None, taxonomy_id=None, shop_location="US"):
@@ -51,7 +50,7 @@ class ListingResource:
             "taxonomy_id":taxonomy_id, "shop_location":shop_location
         }
         
-        json = self.auth.request(endpoint, params=params)
+        json = self.session.request(endpoint, params=params)
 
         return Response[Listing](**json)
     
@@ -63,36 +62,36 @@ class ListingResource:
                   "offset": offset, "keywords": keywords
         }
         
-        response = self.auth.request(endpoint, params=params)
+        response = self.session.request(endpoint, params=params)
         return Response[Listing](**response)
         
     def get_listings_by_receipt_id(self, shop_id: int, receipt_id: int, limit: int = 25, offset: int = 0) -> Response[Listing]:
         endpoint = f"shops/{shop_id}/receipts/{receipt_id}/listings"
         params = {"limit": limit, "offset": offset}
         
-        response = self.auth.request(endpoint, params=params)
+        response = self.session.request(endpoint, params=params)
         return Response[Listing](**response)
     
     def get_listing_properties(self, shop_id: int, listing_id: int):
         endpoint = f"shops/{shop_id}/listings/{listing_id}/properties"
         
-        response = self.auth.request(endpoint)
+        response = self.session.request(endpoint)
         return Response[ListingProperty](**response)
     
     def get_listing_property(self, listing_id: int, property_id: int):
         endpoint = f"listings/{listing_id}/properties/{property_id}"
         
-        response = self.auth.request(endpoint)
+        response = self.session.request(endpoint)
         return ListingProperty(**response)
     
     def get_listing_inventory(self, listing_id: int):
         endpoint = f"listings/{listing_id}/inventory"
-        response = self.auth.request(endpoint)
+        response = self.session.request(endpoint)
         return Inventory(**response)
     
     def update_listing(self, shop_id: int, listing_id: int, **kwargs):
         endpoint = f"shops/{shop_id}/listings/{listing_id}"
-        response = self.auth.request(endpoint, "PUT", data=kwargs)
+        response = self.session.request(endpoint, "PUT", data=kwargs)
         return Listing(**response)
     
     def update_listing_inventory(self, listing_id: int, products: List[dict], price_on_property: Optional[List[int]] = None, quantity_on_property: Optional[List[int]] = None, sku_on_property: Optional[List[int]] = None):
@@ -111,7 +110,7 @@ class ListingResource:
             data["sku_on_property"] = sku_on_property
             
         endpoint = f"listings/{listing_id}/inventory"
-        response = self.auth.request(endpoint, "PUT", json=data)
+        response = self.session.request(endpoint, "PUT", json=data)
         return Inventory(**response)
 
     
@@ -122,5 +121,5 @@ class ListingResource:
         }
         endpoint = "listings/batch"
         
-        response = self.auth.request(endpoint, params=params)
+        response = self.session.request(endpoint, params=params)
         return Response[Listing](**response)
\ No newline at end of file
