@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from etsy_apiv3.utils.APIV3 import EtsyAuth
+from etsy_apiv3.utils.APIV3 import EtsySession
 from etsy_apiv3.utils.Response import Response
 from etsy_apiv3.models.ReceiptModel import Receipt, ReceiptType
 
@@ -14,7 +14,7 @@ class ReceiptResource:
     """
     
     __endpoint = "shops/{shop_id}/receipts"
-    auth: EtsyAuth
+    session: EtsySession
     
     def find(self, shop_id: int, limit=25, offset=0, type: ReceiptType = ReceiptType.UNSHIPPED) -> Response[Receipt]:
         """
@@ -35,7 +35,7 @@ class ReceiptResource:
         
         params = {"limit":limit, "offset":offset}
         params.update(type)
-        json = self.auth.request(endpoint=endpoint, params=params)
+        json = self.session.request(endpoint=endpoint, params=params)
         
         return Response[Receipt](**json)
     
@@ -51,7 +51,7 @@ class ReceiptResource:
             Receipt: Create Receipt Object from json
         """
         endpoint = f"{self.__endpoint.format(shop_id=shop_id)}/{receipt_id}"
-        json = self.auth.request(endpoint=endpoint)
+        json = self.session.request(endpoint=endpoint)
         
         return Receipt(**json)
 
@@ -77,5 +77,5 @@ class ReceiptResource:
             "send_bcc":send_bcc, "note_to_buyer":note_to_buyer
         }
         
-        json = self.auth.request(endpoint=endpoint, method="POST", data=data)
+        json = self.session.request(endpoint=endpoint, method="POST", data=data)
         return Receipt(**json)
\ No newline at end of file
