@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from etsy_apiv3.models.ShopModel import Shop
-from etsy_apiv3.utils.APIV3 import EtsyAuth
+from etsy_apiv3.utils.APIV3 import EtsySession
 from etsy_apiv3.utils.Response import Response
 
 @dataclass
@@ -9,7 +9,7 @@ class ShopResource:
     Shop Resource Of Etsy Api V3.
 
     """
-    auth: EtsyAuth
+    session: EtsySession
     
     def get_shop(self, shop_id: int):
         """
@@ -23,7 +23,7 @@ class ShopResource:
         """
         
         endpoint = f"shops/{shop_id}"
-        response = self.auth.request(endpoint)
+        response = self.session.request(endpoint)
         return Shop(**response)
     
     def find_shops(self, shop_name: str):
@@ -34,7 +34,7 @@ class ShopResource:
             Response: Return Response object of shop list 
         """
         endpoint = "shops"
-        response = self.auth.request(endpoint, params={"shop_name":shop_name})
+        response = self.session.request(endpoint, params={"shop_name":shop_name})
         return Response[Shop](**response)
 
     def find_shop_by_owner_user_id(self, user_id: int):
@@ -48,7 +48,7 @@ class ShopResource:
             Shop: Return A Shop Object
         """
         endpoint = f"users/{user_id}/shops"
-        response = self.auth.request(endpoint)
+        response = self.session.request(endpoint)
         return Shop(**response)
     
     def update_shop(self, shop_id: int, title: str = "", announcement: str = "", sale_message: str = "", digital_sale_message: str = ""):
